A framework that boosts the imputation of 'missForest' by Stekhoven, D.J. and Bühlmann, P. (2012) tools:::Rd_expr_doi("10.1093/bioinformatics/btr597") by harnessing parallel processing and through the fast Gradient Boosted Decision Trees (GBDT) implementation 'LightGBM' by Ke, Guolin et al.(2017) https://papers.nips.cc/paper/6907-lightgbm-a-highly-efficient-gradient-boosting-decision. 'misspi' has the following main advantages: 1. Allows embrassingly parallel imputation on large scale data. 2. Accepts a variety of machine learning models as methods with friendly user portal. 3. Supports multiple initializations methods. 4. Supports early stopping that prohibits unnecessary iterations.
Maintainer: Zhongli Jiang happycatstat@gmail.com
Useful links: